Learn R Programming

qpNCA (version 1.1.6)

calc.ctmax: Calculate Cmax and Tmax

Description

Calculates Cmax and Tmax from raw data for each PK curve defined using by.

Usage

calc.ctmax(x, by = character(0), timevar = "time", depvar = "dv")

Arguments

x

data.frame

by

column names in x indicating grouping variables

timevar

variable name containing the actual sampling time after dose

depvar

variable name containing the dependent variable (e.g., concentration)

Value

A dataset with estimates for the Cmax (maximum concentration) and Tmax (time of first occurence of cmax) parameters: one observation per subject

Details

Input dataset can contain all uncorrected data, including LOQ; estimate first occurence of maximum concentration for each PK curve; if all concentrations are NA, sets Cmax and Tmax also to NA.

Examples

Run this code
# NOT RUN {
example(est.thalf)
ctmax <- x %>% calc.ctmax(by = 'subject')
ctmax %>% head
# }

Run the code above in your browser using DataLab