Estimates lagging and leading times and concentrations. Used by correct.xx functions to estimate lagging and leading timepoints and concentrations for each timepoint.
lag_lead(
x,
nomtimevar1 = NA,
depvar1 = NA,
timevar1 = NA,
lagc = NA,
lagt = NA,
leadc = NA,
leadt = NA,
...
)data.frame
column name in x indicating nominal time after dose
column name in x indicating concentration
column name in x indicating actual time after dose
concentration at previous sampling time
previous sampling time
concentration at next sampling time
next sampling time
ignored
data.frame