powered by
Tabulates what records were added, time deviations and concentration imputations were applied, for each subject.
tab.corr(x, by = character(0), nomtimevar = "time")
concentration dataset created by the correct.time and correct.conc functions, containing time and conc corrected data
column names in x indicating grouping variables
column in x containing the nominal time after dose
dataset with applied corrections (rule number and rule text) listed by by-variable(s) and nominal time
# NOT RUN { example(correct.conc) corrtab <- x %>% tab.corr(by = 'subject') corrtab %>% head # }
Run the code above in your browser using DataLab