Calculates PK parameters for which half-life is not needed in the calculation for each PK curve defined using by.
calc.par(
x,
by = character(0),
tau = NA,
tstart = NA,
tend = NA,
teval = NA,
route = "EV",
method = 1
)contains all data after time/concentration deviation corrections obtained from correct.time and correct.conc
column names in x indicating grouping variables
dosing interval (for multiple dosing); NA (default) for if single dose; x$tau overrides
start time of partial AUC (start>0); NA (default) if not requested; x$tstart overrides
end time of partial AUC; NA (default) if not requested; x$tend overrides
user selected AUC interval; NA (default) if not requested; x$teval overrides
route of drug administration ("EV","IVB","IVI"); x$route overrides
method for trapezoidal rule
1: linear up - linear down
2: linear up - logarithmic down
3: linear before first Tmax, logarithmic after first Tmax
A dataset with estimates for the following parameters, one observation per subject:
| Parameter | Description |
| t0.ok | flags if t=0 concentration could be corrected/imputes. If not, no AUCs starting at t=0 are calculated |
| tlast.ok | flags if there is at least one measurable concentration. If not, no AUClast can be calculated |
| tlast | time of last sample with measurable concentration |
| clast.obs | observed concentration at tlast |
| aucall | auc calculated over all observations, including values below LOQ (which are set to 0) |
| auclast | auc calculated using all observations up to and including the last measurable concentration (clast.obs at tlast) |
| aumcall | aumc calculated over all observations, including values below LOQ (which are set to 0) |
| aumclast | aumc calculated using all observations up to and including the last measurable concentration (clast.obs at tlast) |
| tau | the dosing interval (if specified) |
| calc.tau | flags if AUCtau could be calculated |
| auctau | auc calculated over the dosing interval, only calculated if tau is specified |
| aumctau | aumc calculated over the dosing interval, only calculated if tau is specified |
| teval | user selected AUC interval starting at t=0 (if specified) |
| calc.teval | flags if AUCteval could be calculated |
| aucxx | auc calculated from t=0 up to/including teval, only calculated if teval is specified (xx is substituted by teval) |
| calc.part | flags if AUCpart could be calculated |
| tstart | start time of partial AUC (if specified) |
| tend | end time of partial AUC (if specified) |
| aucx_y | partial auc from time=x up to/including time=y, where x>0, only calculated if tstart and tend are specified |
| c0 | back-extrapolated concentration at t=0 for IV bolus administration |
| area.back.extr | area back-extrapolated to 0 |
# NOT RUN {
example(correct.conc)
par <- x %>% calc.par(by = 'subject')
par %>% head
# }
Run the code above in your browser using DataLab