|
Parameter |
Description |
|
clast.pred |
predicted concentration at tlast |
|
aucinf.obs |
aucinf based on observed concentration at tlast |
|
aucinf.pred |
aucinf based on predicted concentration at tlast |
|
aumcinf.obs |
area under the first moment curve extrapolated to infinity, based on observed concentration at tlast |
|
aumcinf.pred |
area under the first moment curve extrapolated to infinity, based on predicted concentration at tlast |
|
cl.obs, cl.f.obs |
clearance based on aucinf.obs, at steady state based on auctau |
|
cl.pred, cl.f.pred |
clearance based on aucinf.pred |
|
cl.ss, cl.f.ss |
clearance at steady state, based on auctau |
|
mrt.obs |
mean residence time based on aumcinf.obs and aucinf.obs |
|
mrt.pred |
mean residence time based on aumcinf.pred and aucinf.pred |
|
vz.obs, vz.f.obs |
distribution volume based on cl.f.obs, at steady state based on auctau |
|
vz.pred, vz.f.pred |
distribution based on cl.pred/cl.f.pred |
|
vss.obs |
steady-state volume based on cl.obs and mrt.obs |
|
vss.pred |
steady-state volume based on cl.pred and mrt.pred |
|
pctextr.pred |
percentage of AUC extrapolated to infinity, based on aucinf.pred |
|
pctextr.obs |
percentage of AUC extrapolated to infinity, based on aucinf.obs |
|
pctback.pred |
percentage of AUC extrapolated back to 0, based on aucinf.pred |
|
pctback.obs |
percentage of AUC extrapolated back to 0, based on aucinf.obs |
Note: ctmax must be merged separately as those were calculated from uncorrected data.